==> jc-1.4.0.tar.gz: gnu/classpath/VMSystemProperties.h <==
// class gnu.classpath.VMSystemProperties

// class file dependencies
// @dep_class 614330bf1c3b5abe gnu_classpath_VMSystemProperties
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_classpath_VMSystemProperties_H_
#define _JC_gnu_classpath_VMSystemProperties_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Properties$object;

// Typedefs
typedef struct _jc_gnu_classpath_VMSystemProperties$sub_refs	_jc_gnu_classpath_VMSystemProperties$sub_refs;
typedef struct _jc_gnu_classpath_VMSystemProperties$sub_nonrefs	_jc_gnu_classpath_VMSystemProperties$sub_nonrefs;
typedef struct _jc_gnu_classpath_VMSystemProperties$refs	_jc_gnu_classpath_VMSystemProperties$refs;
typedef struct _jc_gnu_classpath_VMSystemProperties$nonrefs	_jc_gnu_classpath_VMSystemProperties$nonrefs;
typedef struct _jc_gnu_classpath_VMSystemProperties$object	_jc_gnu_classpath_VMSystemProperties$object;

typedef const struct _jc_gnu_classpath_VMSystemProperties$vmethods	_jc_gnu_classpath_VMSystemProperties$vmethods;
typedef const struct _jc_gnu_classpath_VMSystemProperties$vtable	_jc_gnu_classpath_VMSystemProperties$vtable;
typedef const struct _jc_gnu_classpath_VMSystemProperties$vtype	_jc_gnu_classpath_VMSystemProperties$vtype;

// Constructors
extern void _jc_gnu_classpath_VMSystemProperties$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_classpath_VMSystemProperties$object *);

// Static methods
extern void _jc_gnu_classpath_VMSystemProperties$method$postInit$90cdcf0a3f08fd24(_jc_env *, struct _jc_java_util_Properties$object *);
extern void _jc_gnu_classpath_VMSystemProperties$method$preInit$291273a306e01060(_jc_env *, struct _jc_java_util_Properties$object *);

// Virtual methods structure
struct _jc_gnu_classpath_VMSystemProperties$vmethods {
};

// Vtable
struct _jc_gnu_classpath_VMSystemProperties$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_classpath_VMSystemProperties$vmethods	gnu_classpath_VMSystemProperties;
};

// Vtype
struct _jc_gnu_classpath_VMSystemProperties$vtype {
	_jc_type			type;
	_jc_gnu_classpath_VMSystemProperties$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_classpath_VMSystemProperties$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_classpath_VMSystemProperties$refs {
    _jc_gnu_classpath_VMSystemProperties$sub_refs	gnu_classpath_VMSystemProperties;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_classpath_VMSystemProperties$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_classpath_VMSystemProperties$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_classpath_VMSystemProperties$sub_nonrefs	gnu_classpath_VMSystemProperties;
};

// Object instance structure
struct _jc_gnu_classpath_VMSystemProperties$object {
	_jc_gnu_classpath_VMSystemProperties$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_classpath_VMSystemProperties$vtype	*vtype;
	_jc_gnu_classpath_VMSystemProperties$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_classpath_VMSystemProperties$vtype _jc_gnu_classpath_VMSystemProperties$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_classpath_VMSystemProperties, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_classpath_VMSystemProperties$class_object;

#endif	/* _JC_gnu_classpath_VMSystemProperties_H_ */

==> jc-1.4.6.tar.gz: gnu/classpath/VMSystemProperties.h <==
// class gnu.classpath.VMSystemProperties

// class file dependencies
// @dep_class 614330bf1c3b5abe gnu_classpath_VMSystemProperties
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_classpath_VMSystemProperties_H_
#define _JC_gnu_classpath_VMSystemProperties_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Properties$object;

// Typedefs
typedef struct _jc_gnu_classpath_VMSystemProperties$sub_refs	_jc_gnu_classpath_VMSystemProperties$sub_refs;
typedef struct _jc_gnu_classpath_VMSystemProperties$sub_nonrefs	_jc_gnu_classpath_VMSystemProperties$sub_nonrefs;
typedef struct _jc_gnu_classpath_VMSystemProperties$refs	_jc_gnu_classpath_VMSystemProperties$refs;
typedef struct _jc_gnu_classpath_VMSystemProperties$nonrefs	_jc_gnu_classpath_VMSystemProperties$nonrefs;
typedef struct _jc_gnu_classpath_VMSystemProperties$object	_jc_gnu_classpath_VMSystemProperties$object;

typedef const struct _jc_gnu_classpath_VMSystemProperties$vmethods	_jc_gnu_classpath_VMSystemProperties$vmethods;
typedef const struct _jc_gnu_classpath_VMSystemProperties$vtable	_jc_gnu_classpath_VMSystemProperties$vtable;
typedef const struct _jc_gnu_classpath_VMSystemProperties$vtype	_jc_gnu_classpath_VMSystemProperties$vtype;

// Constructors
extern void _jc_gnu_classpath_VMSystemProperties$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_classpath_VMSystemProperties$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_gnu_classpath_VMSystemProperties$method$postInit$90cdcf0a3f08fd24(_jc_env *, struct _jc_java_util_Properties$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_classpath_VMSystemProperties$method$preInit$291273a306e01060(_jc_env *, struct _jc_java_util_Properties$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_classpath_VMSystemProperties$vmethods {
};

// Vtable
struct _jc_gnu_classpath_VMSystemProperties$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_classpath_VMSystemProperties$vmethods	gnu_classpath_VMSystemProperties;
};

// Vtype
struct _jc_gnu_classpath_VMSystemProperties$vtype {
	_jc_type			type;
	_jc_gnu_classpath_VMSystemProperties$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_classpath_VMSystemProperties$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_classpath_VMSystemProperties$refs {
    _jc_gnu_classpath_VMSystemProperties$sub_refs	gnu_classpath_VMSystemProperties;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_classpath_VMSystemProperties$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_classpath_VMSystemProperties$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_classpath_VMSystemProperties$sub_nonrefs	gnu_classpath_VMSystemProperties;
};

// Object instance structure
struct _jc_gnu_classpath_VMSystemProperties$object {
	_jc_gnu_classpath_VMSystemProperties$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_classpath_VMSystemProperties$vtype	*vtype;
	_jc_gnu_classpath_VMSystemProperties$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_classpath_VMSystemProperties$vtype _jc_gnu_classpath_VMSystemProperties$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_classpath_VMSystemProperties, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_classpath_VMSystemProperties$class_object;

#endif	/* _JC_gnu_classpath_VMSystemProperties_H_ */
